@@ -3,11 +3,6 @@
 }
 
 
-`as_haven` <- function(x, ...) {
-    UseMethod("as.haven")
-}
-
-
 `as.haven.default` <- function(x, ...) {
     interactive <- TRUE
 
@@ -40,7 +35,8 @@
     attributes(x) <- NULL # or x <- unclass(x), but I find this cleaner
 
     if (possibleNumeric_(x) || all(is.na(x))) {
-        x <- as.numeric(x)
+        x <- as.double(x)
+        attr(x, "class") <- "double"
     }
 
     if (!is.null(na_index)) {
@@ -101,7 +97,6 @@
             attrx$labels <- labels
         }
     }
-
     #------------------------------------------
 
     attrx$na_index <- NULL
@@ -111,7 +106,7 @@
     # detour until ReadStat deals with integers
     attrx$class <- unique(c(
             "haven_labelled_spss", "haven_labelled", "vctrs_vctr",
-            setdiff(attrx$class, c("declared", "double", "integer")),
+            setdiff(attrx$class, c("declared", "double", "integer", "character")),
             class(x)
     ))
     #------------------------------------------
